# client_for3party
A simple, reliable, and easy-to-debug unified client for third-party APIs, designed to provide users with an efficient API interface management and calling experience.

## Usage
1. [Base usage](https://github.com/oerlock/client_for3party/blob/main/examples/a1_basic_usage.py)
